<?php
/*********************************************
  CPG Dragonfly™ CMS
  ********************************************
  Copyright © 2004-2005 by CPG-Nuke Dev Team
  http://www.dragonflycms.com

  Dragonfly is released under the terms and conditions
  of the GNU GPL version 2 or any later version

  $Source: /cvs/html/language/english/forums.php,v $
  $Revision: 9.9.8.2 $
  $Author: phoenix $
  $Date: 2011/12/13 12:29:24 $

  If editing this file please edit the second 
  or right side of the pair of terms.
Encoding test: n-array summation ∑ latin ae w/ acute ǽ
*******************************************************/
if (!defined('CPG_NUKE')) { exit; }
global $lang;
$lang = array(
    'ENCODING' => 'utf-8',
    'DIRECTION' => 'ltr',
    'LEFT' => 'left',
    'RIGHT' => 'right',
    'DATE_FORMAT' => 'd M Y',
    'TRANSLATION' => 'UTF-8 Encoded by the Dragonfly™ CMS Dev Team',
    'Forum' => 'Forum',
    'Category' => 'Category',
    'Topic' => 'Topic',
    'Topics' => 'Topics',
    'Replies' => 'Replies',
    'Views' => 'Views',
    'Post' => 'Post',
    'Posts' => 'Posts',
    'Posted' => 'Posted',
    'Username' => 'Username',
    'Password' => 'Password',
    'Email' => 'E-mail',
    'Poster' => 'Poster',
    'Author' => 'Author',
    'Time' => 'Time',
    'Hours' => 'Hours',
    'Message' => 'Message',
    '1_Day' => '1 Day',
    '7_Days' => '7 Days',
    '2_Weeks' => '2 Weeks',
    '1_Month' => '1 Month',
    '3_Months' => '3 Months',
    '6_Months' => '6 Months',
    '1_Year' => '1 Year',
    'Go' => 'Go',
    'Jump_to' => 'Jump to',
    'Submit' => 'Submit',
    'Reset' => 'Reset',
    'Cancel' => 'Cancel',
    'Preview' => 'Preview',
    'Confirm' => 'Confirm',
    'Spellcheck' => 'Spellcheck',
    'Yes' => 'Yes',
    'No' => 'No',
    'Enabled' => 'Enabled',
    'Disabled' => 'Disabled',
    'Error' => 'Error',
    'Next' => 'Next',
    'Previous' => 'Previous',
    'Goto_page' => 'Go to page',
    'Joined' => 'Joined',
    'IP_Address' => 'IP Address',
    'Select_forum' => 'Select a forum',
    'View_latest_post' => 'View latest post',
    'View_newest_post' => 'View newest post',
    'Page_of' => 'Page <b>%d</b> of <b>%d</b>',
    'ICQ' => 'ICQ Number',
    'AIM' => 'AIM Address',
    'MSNM' => 'MSN Messenger',
    'YIM' => 'Yahoo Messenger',
    'Forum_Index' => '%s Forum Index',
    'Post_new_topic' => 'Post new topic',
    'Reply_to_topic' => 'Reply to topic',
    'Reply_with_quote' => 'Reply with quote',
    'Click_return_topic' => 'Click %sHere%s to return to the topic.',
    'Click_return_login' => 'Click %sHere%s to try again.',
    'Click_return_forum' => 'Click %sHere%s to return to the forum.',
    'Click_view_message' => 'Click %sHere%s to view your message.',
    'Click_return_modcp' => 'Click %sHere%s to return to the Moderator Control Panel.',
    'Click_return_group' => 'Click %sHere%s to return to group information.',
    'Admin_panel' => 'Go to Administration Panel',
    'Board_disable' => 'Sorry, but this board is currently unavailable.  Please try again later.',
    'Admin_online_color' => '%sAdministrator%s',
    'Mod_online_color' => '%sModerator%s',
    'You_last_visit' => 'You last visited on %s',
    'Current_time' => 'The time now is %s',
    'Search_new' => 'View posts since last visit',
    'Search_last_24' => 'View posts last 24 hours',
    'Search_your_posts' => 'View your posts',
    'Search_unanswered' => 'View unanswered posts',
    'Register' => 'Register',
    'Profile' => 'Profile',
    'Edit_profile' => 'Edit your profile',
    'Search' => 'Search',
    'Memberlist' => 'Memberlist',
    'FAQ' => 'Forum FAQ',
    'BBCode_guide' => 'BBCode Guide',
    'Usergroups' => 'Usergroups',
    'Last_Post' => 'Last Post',
    'Moderator' => 'Moderator',
    'Moderators' => 'Moderators',
    'no_moderators' => 'no moderators',
    'Subforum' => 'Subforum',
    'Subforums' => 'Subforums',
    'Subforum_of' => 'Subforum of',
    'Not_Subforum' => 'Not a Subforum',
    'No_new_posts_last_visit' => 'No new posts since your last visit.',
    'No_new_posts' => 'No new posts',
    'No_new_sub_posts' => 'Subforum no new posts',
    'New_posts' => 'New posts',
    'New_sub_posts' => 'Subforum new posts',
    'New_post' => 'New post',
    'No_new_posts_hot' => 'No new posts [Popular]',
    'New_posts_hot' => 'New posts [Popular]',
    'No_new_posts_locked' => 'No new posts [Locked]',
    'New_posts_locked' => 'New posts [Locked]',
    'Forum_is_locked' => 'Forum is locked',
    'Subforum_is_locked' => 'Subforum is locked',
    'Login' => 'Log in',
    'Logout' => 'Log out',
    'Log_me_in' => 'Log me on automatically each visit',
	'Admin_color' => 'Administrator Color',
	'Moderator_color' => 'Moderator Color',
	'Member_color' => 'Member Color',
	'Allow_guest_captcha' => 'Captcha (security code) required for guests to post.',
	'Allow_online_posts' => 'Display member online status in each post.',
    // Index page 
    'Index' => 'Index',
    'No_Posts' => 'No Posts',
    'No_forums' => 'This board has no forums',
    'Private_Message' => 'Private Message',
    'Private_Messages' => 'Private Messages',
    'Who_is_Online' => 'Who is Online',
    'Who_online_now' => 'Online now',
    'Who_online_today' => 'Online today',
    'Mark_all_forums' => 'Mark all forums read',
    'Forums_marked_read' => 'All forums have been marked read',
    'Total_posts_topics' => 'Our members have posted a total of %s posts in %s topics, and %s archived posts in %s archived topics.',
    // Viewforum 
    'View_forum' => 'View Forum',
    'Forum_not_exist' => 'The forum you selected does not exist.',
    'Reached_on_error' => 'You have reached this page in error.',
    'Display_topics' => 'Display topics from previous',
    'All_Topics' => 'All Topics',
    'Topic_Announcement' => '<b>Announcement:</b>',
    'Topic_Sticky' => '<b>Sticky:</b>',
    'Topic_Moved' => '<b>Moved:</b>',
    'Topic_Poll' => '<b>[ Poll ]</b>',
    'Mark_all_topics' => 'Mark all topics read',
    'Topics_marked_read' => 'The topics for this forum have now been marked read.',
    'Rules_post_can' => 'You <b>can</b> post new topics in this forum',
    'Rules_post_cannot' => 'You <b>cannot</b> post new topics in this forum',
    'Rules_reply_can' => 'You <b>can</b> reply to topics in this forum',
    'Rules_reply_cannot' => 'You <b>cannot</b> reply to topics in this forum',
    'Rules_edit_can' => 'You <b>can</b> edit your posts in this forum',
    'Rules_edit_cannot' => 'You <b>cannot</b> edit your posts in this forum',
    'Rules_delete_can' => 'You <b>can</b> delete your posts in this forum',
    'Rules_delete_cannot' => 'You <b>cannot</b> delete your posts in this forum',
    'Rules_vote_can' => 'You <b>can</b> vote in polls in this forum',
    'Rules_vote_cannot' => 'You <b>cannot</b> vote in polls in this forum',
    'Rules_moderate' => 'You <b>can</b> %smoderate this forum%s',
    'No_topics_post_one' => 'There are no posts in this forum.<br />Click on the <b>Post New Topic</b> link on this page to post one.',
    'Stop_watching_forum' => 'Stop watching this forum',
    'Start_watching_forum' => 'Watch this forum for posts',
    'No_longer_watching_forum' => 'You are no longer watching this forum',
    'You_are_watching_forum' => 'You are now watching this forum',
	'Forum_watch' => 'Forum Watch',
    // Viewtopic 
    'View_topic' => 'View topic',
    'Guest' => 'Guest',
    'Post_subject' => 'Post subject',
    'View_next_topic' => 'View next topic',
    'View_previous_topic' => 'View previous topic',
    'Submit_vote' => 'Submit Vote',
    'View_results' => 'View Results',
    'No_newer_topics' => 'There are no newer topics in this forum',
    'No_older_topics' => 'There are no older topics in this forum',
    'Topic_post_not_exist' => 'The topic or post you requested does not exist',
    'No_posts_topic' => 'No posts exist for this topic',
    'Display_posts' => 'Display posts from previous',
    'All_Posts' => 'All Posts',
    'Newest_First' => 'Newest First',
    'Oldest_First' => 'Oldest First',
    'Back_to_top' => 'Back to top',
    'Read_profile' => 'View user\'s profile',
    'Send_email' => 'Send e-mail',
    'Visit_website' => 'Visit poster\'s website',
    'ICQ_status' => 'ICQ Status',
    'Edit_delete_post' => 'Edit/Delete this post',
    'View_IP' => 'View IP address of poster',
    'Delete_post' => 'Delete this post',
    'wrote' => 'wrote',
    'Quote' => 'Quote',
    'Code' => 'Code',
    'PHPCode' => 'PHP',
    'Edited_time_total' => 'Last edited by %s on %s; edited %d time in total',
    'Edited_times_total' => 'Last edited by %s on %s; edited %d times in total',
    'Lock_topic' => 'Lock this topic',
    'Unlock_topic' => 'Unlock this topic',
    'Move_topic' => 'Move this topic',
    'Delete_topic' => 'Delete this topic',
    'Split_topic' => 'Split this topic',
	'New_topic_notify' => 'New Topic Notification',
    'Stop_watching_topic' => 'Stop watching this topic',
    'Start_watching_topic' => 'Watch this topic for replies',
    'No_longer_watching' => 'You are no longer watching this topic',
    'You_are_watching' => 'You are now watching this topic',
	'Topic_watch' => 'Topic Watch',
    'Total_votes' => 'Total Votes',
	'Online' => 'Online',
	'Offline' => 'Offline',
    // Posting/Replying 
    'Message_body' => 'Message body',
    'Topic_review' => 'Topic review',
    'No_post_mode' => 'No post mode specified',
    'Post_a_new_topic' => 'Post a new topic',
    'Post_a_reply' => 'Post a reply',
    'Post_topic_as' => 'Post topic as',
    'Edit_Post' => 'Edit post',
    'Options' => 'Options',
    'Post_Announcement' => 'Announcement',
    'Post_Sticky' => 'Sticky',
    'Post_Normal' => 'Normal',
    'Confirm_delete' => 'Are you sure you want to delete this post?',
    'Confirm_delete_poll' => 'Are you sure you want to delete this poll?',
    'Flood_Error' => 'You cannot make another post so soon after your last; please try again in a short while.',
    'Empty_subject' => 'You must specify a subject when posting a new topic.',
    'Empty_message' => 'You must enter a message when posting.',
    'Forum_locked' => 'This forum is locked: you cannot post, reply to, or edit topics.',
    'Topic_locked' => 'This topic is locked: you cannot edit posts or make replies.',
    'No_post_id' => 'No post ID was specified',
    'No_topic_id' => 'You must select a topic to reply to',
    'No_valid_mode' => 'You can only post, reply, edit, or quote messages. Please return and try again.',
    'No_such_post' => 'There is no such post. Please return and try again.',
    'Edit_own_posts' => 'Sorry, but you can only edit your own posts.',
    'Delete_own_posts' => 'Sorry, but you can only delete your own posts.',
    'Cannot_delete_replied' => 'Sorry, but you may not delete posts that have been replied to.',
    'Cannot_delete_poll' => 'Sorry, but you cannot delete an active poll.',
    'Empty_poll_title' => 'You must enter a title for your poll.',
    'To_few_poll_options' => 'You must enter at least two poll options.',
    'To_many_poll_options' => 'You have tried to enter too many poll options.',
    'Post_has_no_poll' => 'This post has no poll.',
    'Already_voted' => 'You have already voted in this poll.',
    'No_vote_option' => 'You must specify an option when voting.',
    'Add_poll' => 'Add a Poll',
    'Add_poll_explain' => 'If you do not want to add a poll to your topic, leave the fields blank.',
    'Poll_question' => 'Poll question',
    'Poll_option' => 'Poll option',
    'Add_option' => 'Add option',
    'Update' => 'Update',
    'Delete' => 'Delete',
    'Poll_for' => 'Run poll for',
    'Days' => 'Days',
    'Poll_for_explain' => '[ Enter 0 or leave blank for a never-ending poll ]',
    'Delete_poll' => 'Delete Poll',
    'Disable_HTML_post' => 'Disable HTML in this post',
    'Disable_BBCode_post' => 'Disable BBCode in this post',
    'Disable_Smilies_post' => 'Disable Smilies in this post',
    'HTML_is_ON' => 'HTML is <u>ON</u>',
    'HTML_is_OFF' => 'HTML is <u>OFF</u>',
    'BBCode_is_ON' => '%sBBCode%s is <u>ON</u>',
    'BBCode_is_OFF' => '%sBBCode%s is <u>OFF</u>',
    'Smilies_are_ON' => 'Smilies are <u>ON</u>',
    'Smilies_are_OFF' => 'Smilies are <u>OFF</u>',
    'Attach_signature' => 'Attach signature (signatures can be changed in profile)',
    'Notify' => 'Notify me when a reply is posted',
    'Stored' => 'Your message has been entered successfully.',
    'Deleted' => 'Your message has been deleted successfully.',
    'Poll_delete' => 'Your poll has been deleted successfully.',
    'Vote_cast' => 'Your vote has been cast.',
    'Topic_reply_notification' => 'Topic Reply Notification',
    'Emoticons' => 'Emoticons',
    'More_emoticons' => 'View more Emoticons',
    'Private_Messaging' => 'Private Messaging',
    'Login_check_pm' => 'Log in to check your private messages',
    'New_pms' => 'You have %d new messages',
    'New_pm' => 'You have %d new message',
    'No_new_pm' => 'You have no new messages',
    'Unread_pms' => 'You have %d unread messages',
    'Unread_pm' => 'You have %d unread message',
    'No_unread_pm' => 'You have no unread messages',
    'You_new_pm' => 'A new private message is waiting for you in your Inbox',
    'You_new_pms' => 'New private messages are waiting for you in your Inbox',
    'You_no_new_pm' => 'No new private messages are waiting for you',
    'Unread_message' => 'Unread message',
    'Read_message' => 'Read message',
    'Read_pm' => 'Read message',
    'Post_new_pm' => 'Post message',
    'Post_reply_pm' => 'Reply to message',
    'Post_quote_pm' => 'Quote message',
    'Edit_pm' => 'Edit message',
    'Inbox' => 'Inbox',
    'Outbox' => 'Outbox',
    'Savebox' => 'Savebox',
    'Sentbox' => 'Sentbox',
    'Flag' => 'Flag',
    'Subject' => 'Subject',
    'From' => 'From',
    'To' => 'To',
    'Date' => 'Date',
    'Mark' => 'Mark',
    'Sent' => 'Sent',
    'Saved' => 'Saved',
    'Delete_marked' => 'Delete Marked',
    'Delete_all' => 'Delete All',
    'Save_marked' => 'Save Marked',
    'Save_message' => 'Save Message',
    'Delete_message' => 'Delete Message',
    'Display_messages' => 'Display messages from previous',
    'All_Messages' => 'All Messages',
    'No_messages_folder' => 'You have no messages in this folder',
    'PM_disabled' => 'Private messaging has been disabled on this board.',
    'Cannot_send_privmsg' => 'Sorry, but the administrator has prevented you from sending private messages.',
    'No_to_user' => 'You must specify a username to whom to send this message.',
    'No_such_user' => 'Sorry, but no such user exists.',
    'Disable_HTML_pm' => 'Disable HTML in this message',
    'Disable_BBCode_pm' => 'Disable BBCode in this message',
    'Disable_Smilies_pm' => 'Disable Smilies in this message',
    'Message_sent' => 'Your message has been sent.',
    'Click_return_inbox' => 'Click %sHere%s to return to your Inbox',
    'Click_return_index' => 'Click %sHere%s to return to the Index',
    'Send_a_new_message' => 'Send a new private message',
    'Send_a_reply' => 'Reply to a private message',
    'Edit_message' => 'Edit private message',
    'Notification_subject' => 'New Private Message has arrived!',
    'Find_username' => 'Find a username',
    'Find' => 'Find',
    'No_match' => 'No matches found.',
    'No_such_folder' => 'No such folder exists',
    'No_folder' => 'No folder specified',
    'Mark_all' => 'Mark all',
    'Unmark_all' => 'Unmark all',
    'Confirm_delete_pm' => 'Are you sure you want to delete this message?',
    'Confirm_delete_pms' => 'Are you sure you want to delete these messages?',
    'Inbox_size' => 'Your Inbox is %d%% full',
    'Sentbox_size' => 'Your Sentbox is %d%% full',
    'Savebox_size' => 'Your Savebox is %d%% full',
    'Click_view_privmsg' => 'Click %sHere%s to visit your Inbox',
    // Profile 
    'Viewing_user_profile' => 'Viewing profile :: %s',
    'About_user' => 'All about %s',
    'Preferences' => 'Preferences',
    'Items_required' => 'Items marked with a * are required unless stated otherwise.',
    'Registration_info' => 'Registration Information',
    'Profile_info' => 'Profile Information',
    'Profile_info_warn' => 'This information will be publicly viewable',
    'Avatar_panel' => 'Avatar control panel',
    'Avatar_gallery' => 'Avatar gallery',
    'Website' => 'Website',
    'Location' => 'Location',
    'Contact' => 'Contact',
    'Email_address' => 'E-mail address',
    'Send_private_message' => 'Send private message',
    'Hidden_email' => '[ Hidden ]',
    'Search_user_posts' => 'Find all posts by %s',
    'Interests' => 'Interests',
    'Occupation' => 'Occupation',
    'Poster_rank' => 'Poster rank',
    'Total_posts' => 'Total posts',
    'User_post_pct_stats' => '%.2f%% of total',
    'User_post_day_stats' => '%.2f posts per day',
    'No_user_id_specified' => 'Sorry, but that user does not exist.',
    'Wrong_Profile' => 'You cannot modify a profile that is not your own.',
    'Only_one_avatar' => 'Only one type of avatar can be specified',
    'Incomplete_URL' => 'The URL you entered is incomplete',
    'Wrong_remote_avatar_format' => 'The URL of the remote avatar is not valid',
    'No_send_account_inactive' => 'Sorry, but your password cannot be retrieved because your account is currently inactive. Please contact the forum administrator for more information.',
    'Always_smile' => 'Always enable Smilies',
    'Always_html' => 'Always allow HTML',
    'Always_bbcode' => 'Always allow BBCode',
    'Always_add_sig' => 'Always attach my signature',
    'Always_notify' => 'Always notify me of replies',
    'Always_notify_explain' => 'Sends an e-mail when someone replies to a topic you have posted in. This can be changed whenever you post.',
    'Board_style' => 'Board Style',
    'Board_lang' => 'Board Language',
    'No_themes' => 'The template you selected has no themes attached to it. To create a new theme click the Create New link on the left hand panel',
    'Timezone' => 'Timezone',
    'Date_format' => 'Date Format',
    'Date_format_explain' => 'The syntax used is identical to the PHP <a href=\'http://www.php.net/date\' target=\'_other\'>date()</a> function.',
    'Signature' => 'Signature',
    'Signature_explain' => 'This is a block of text that can be added to posts you make. There is a %d character limit',
    'Public_view_email' => 'Always show my e-mail address',
    'Avatar' => 'Avatar',
    'Upload_Avatar_URL_explain' => 'Enter the URL of the location containing the Avatar image, it will be copied to this site.',
    'Select_category' => 'Select category',
    'Notify_on_privmsg' => 'Notify on new Private Message',
    'Popup_on_privmsg' => 'Pop up window on new Private Message',
    'Popup_on_privmsg_explain' => 'Some templates may open a new window to inform you when new private messages arrive.',
    'Hide_user' => 'Hide your online status',
    'Profile_updated' => 'Your profile has been updated',
    'Profile_updated_inactive' => 'Your profile has been updated. However, you have changed vital details, thus your account is now inactive. Check your e-mail to find out how to reactivate your account, or if admin activation is required, wait for the administrator to reactivate it.',
    'Signature_too_long' => 'Your signature is too long.',
    'Fields_empty' => 'You must fill in the required fields.',
    'Send_email_msg' => 'Send an e-mail message',
    'No_user_specified' => 'No user was specified',
    'User_prevent_email' => 'This user does not wish to receive e-mail. Try sending them a private message.',
    'User_not_exist' => 'That user does not exist',
    'CC_email' => 'Send a copy of this e-mail to yourself',
    'Email_message_desc' => 'This message will be sent as plain text, so do not include any HTML or BBCode. The return address for this message will be set to your e-mail address.',
    'Flood_email_limit' => 'You cannot send another e-mail at this time. Try again later.',
    'Recipient' => 'Recipient',
    'Email_sent' => 'The e-mail has been sent.',
    'Empty_subject_email' => 'You must specify a subject for the e-mail.',
    'Empty_message_email' => 'You must enter a message to be e-mailed.',
    // Memberslist 
    'Select_sort_method' => 'Select sort method',
    'Sort' => 'Sort',
    'Sort_Top_Ten' => 'Top Ten Posters',
    'Sort_Joined' => 'Joined Date',
    'Sort_Username' => 'Username',
    'Sort_Location' => 'Location',
    'Sort_Posts' => 'Posts',
    'Sort_Email' => 'Email',
    'Sort_Website' => 'Website',
    'Sort_Ascending' => 'Ascending',
    'Sort_Descending' => 'Descending',
    'Order' => 'Order',
    // Groups 
    'Group_Control_Panel' => 'Group Control Panel',
    'Group_member_details' => 'Group Membership Details',
    'Group_member_join' => 'Join a Group',
    'Group_Information' => 'Group Information',
    'Group_name' => 'Group name',
    'Group_description' => 'Group description',
    'Group_membership' => 'Group membership',
    'Group_Members' => 'Group Members',
    'Group_Moderator' => 'Group Moderator',
    'Pending_members' => 'Pending Members',
    'Group_type' => 'Group type',
    'Group_open' => 'Open group',
    'Group_closed' => 'Closed group',
    'Group_hidden' => 'Hidden group',
    'Current_memberships' => 'Current memberships',
    'Non_member_groups' => 'Non-member groups',
    'Memberships_pending' => 'Memberships pending',
    'No_groups_exist' => 'No Groups Exist',
    'Group_not_exist' => 'That user group does not exist',
    'Join_group' => 'Join Group',
    'No_group_members' => 'This group has no members',
    'Group_hidden_members' => 'This group is hidden; you cannot view its membership',
    'No_pending_group_members' => 'This group has no pending members',
    'Group_joined' => 'You have successfully subscribed to this group.<br />You will be notified when your subscription is approved by the group moderator.',
    'Group_request' => 'A request to join your group has been made.',
    'Group_approved' => 'Your request has been approved.',
    'Group_added' => 'You have been added to this usergroup.',
    'Already_member_group' => 'You are already a member of this group',
    'User_is_member_group' => 'User is already a member of this group',
    'Group_type_updated' => 'Successfully updated group type.',
    'Could_not_add_user' => 'The user you selected does not exist.',
    'Could_not_anon_user' => 'You cannot make Anonymous a group member.',
    'Confirm_unsub' => 'Are you sure you want to unsubscribe from this group?',
    'Confirm_unsub_pending' => 'Your subscription to this group has not yet been approved; are you sure you want to unsubscribe?',
    'Unsub_success' => 'You have been un-subscribed from this group.',
    'Approve_selected' => 'Approve Selected',
    'Deny_selected' => 'Deny Selected',
    'Not_logged_in' => 'You must be logged in to join a group.',
    'Remove_selected' => 'Remove Selected',
    'Add_member' => 'Add Member',
    'Not_group_moderator' => 'You are not this group\'s moderator, therefore you cannot perform that action.',
    'Login_to_join' => 'Log in to join or manage group memberships',
    'This_open_group' => 'This is an open group: click to request membership',
    'This_closed_group' => 'This is a closed group: no more users accepted',
    'This_hidden_group' => 'This is a hidden group: automatic user addition is not allowed',
    'Member_this_group' => 'You are a member of this group',
    'Pending_this_group' => 'Your membership of this group is pending',
    'Are_group_moderator' => 'You are the group moderator',
    'None' => 'None',
    'Subscribe' => 'Subscribe',
    'Unsubscribe' => 'Unsubscribe',
    'View_Information' => 'View Information',
    // Search 
    'Search_query' => 'Search Query',
    'Search_options' => 'Search Options',
    'Search_keywords' => 'Search for Keywords',
    'Search_keywords_explain' => 'You can use <u>AND</u> to define words which must be in the results, <u>OR</u> to define words which may be in the result and <u>NOT</u> to define words which should not be in the result. Use * as a wildcard for partial matches',
    'Search_author' => 'Search for Author',
    'Search_author_explain' => 'Use * as a wildcard for partial matches',
    'Search_for_any' => 'Search for any terms or use query as entered',
    'Search_for_all' => 'Search for all terms',
    'Search_title_msg' => 'Search topic title and message text',
    'Search_msg_only' => 'Search message text only',
    'Return_first' => 'Return first',
    'characters_posts' => 'characters of posts',
    'Search_previous' => 'Search previous',
    'Sort_by' => 'Sort by',
    'Sort_Time' => 'Post Time',
    'Sort_Post_Subject' => 'Post Subject',
    'Sort_Topic_Title' => 'Topic Title',
    'Sort_Author' => 'Author',
    'Sort_Forum' => 'Forum',
    'Display_results' => 'Display results as',
    'All_available' => 'All available',
    'No_searchable_forums' => 'You do not have permissions to search any forum on this site.',
    'No_search_match' => 'No topics or posts met your search criteria',
    'Found_search_match' => 'Search found %d match',
    'Found_search_matches' => 'Search found %d matches',
    'Close_window' => 'Close Window',
    // Auth related entries 
    // Note the %s will be replaced with one of the following "user" arrays 
    'Sorry_auth_announce' => 'Sorry, but only %s can post announcements in this forum.',
    'Sorry_auth_sticky' => 'Sorry, but only %s can post sticky messages in this forum.',
    'Sorry_auth_read' => 'Sorry, but only %s can read topics in this forum.',
    'Sorry_auth_post' => 'Sorry, but only %s can post topics in this forum.',
    'Sorry_auth_reply' => 'Sorry, but only %s can reply to posts in this forum.',
    'Sorry_auth_edit' => 'Sorry, but only %s can edit posts in this forum.',
    'Sorry_auth_delete' => 'Sorry, but only %s can delete posts in this forum.',
    'Sorry_auth_vote' => 'Sorry, but only %s can vote in polls in this forum.',
    'Auth_Anonymous_Users' => '<b>anonymous users</b>',
    'Auth_Registered_Users' => '<b>registered users</b>',
    'Auth_Users_granted_access' => '<b>users granted special access</b>',
    'Auth_Moderators' => '<b>moderators</b>',
    'Auth_Administrators' => '<b>administrators</b>',
    'Not_Moderator' => 'Not Moderator',
    'Not_Authorised' => 'Not Authorised',
    'You_been_banned' => 'You have been banned from this forum.<br />Please contact the webmaster or board administrator for more information.',
    'Forum_Location' => 'Forum Location',
    'Last_updated' => 'Last Updated',
    'Forum_index' => 'Forum index',
    'Logging_on' => 'Logging on',
    'Posting_message' => 'Posting a message',
    'Searching_forums' => 'Searching forums',
    'Viewing_profile' => 'Viewing profile',
    'Viewing_online' => 'Viewing who is online',
    'Viewing_member_list' => 'Viewing member list',
    'Viewing_priv_msgs' => 'Viewing Private Messages',
    'Viewing_FAQ' => 'Viewing FAQ',
    // Moderator Control Panel 
    'Mod_CP' => 'Moderator Control Panel',
    'Mod_CP_explain' => 'Using the form below you can perform mass moderation operations on this forum. You can lock, unlock, move or delete any number of topics.',
    'Select' => 'Select',
    'Move' => 'Move',
    'Lock' => 'Lock',
    'Unlock' => 'Unlock',
    'Topics_Removed' => 'The selected topics have been successfully removed from the database.',
    'Topics_Locked' => 'The selected topics have been locked.',
    'Topics_Moved' => 'The selected topics have been moved.',
    'Topics_Unlocked' => 'The selected topics have been unlocked.',
    'No_Topics_Moved' => 'No topics were moved.',
    'Confirm_delete_topic' => 'Are you sure you want to remove the selected topic/s?',
    'Confirm_lock_topic' => 'Are you sure you want to lock the selected topic/s?',
    'Confirm_unlock_topic' => 'Are you sure you want to unlock the selected topic/s?',
    'Confirm_move_topic' => 'Are you sure you want to move the selected topic/s?',
    'Move_to_forum' => 'Move to forum',
    'Leave_shadow_topic' => 'Leave shadow topic in old forum.',
    'Split_Topic' => 'Split Topic Control Panel',
    'Split_Topic_explain' => 'Using the form below you can split a topic in two, either by selecting the posts individually or by splitting at a selected post',
    'Split_title' => 'New topic title',
    'Split_forum' => 'Forum for new topic',
    'Split_posts' => 'Split selected posts',
    'Split_after' => 'Split from selected post',
    'Topic_split' => 'The selected topic has been split successfully',
    'Too_many_error' => 'You have selected too many posts. You can only select one post to split a topic after!',
    'None_selected' => 'You have not selected any topics to perform this operation on. Please go back and select at least one.',
    'New_forum' => 'New forum',
    'This_posts_IP' => 'IP address for this post',
    'Other_IP_this_user' => 'Other IP addresses this user has posted from',
    'Users_this_IP' => 'Users posting from this IP address',
    'IP_info' => 'IP Information',
    'Lookup_IP' => 'Look up IP address',
    // Timezones ... for display on each page 
    // The numericals should not be changed, only the word hours
    'All_times' => 'All times are %s',
    '-12' => 'GMT - 12 Hours',
    '-11' => 'GMT - 11 Hours',
    '-10' => 'GMT - 10 Hours',
    '-9' => 'GMT - 9 Hours',
    '-8' => 'GMT - 8 Hours',
    '-7' => 'GMT - 7 Hours',
    '-6' => 'GMT - 6 Hours',
    '-5' => 'GMT - 5 Hours',
    '-4' => 'GMT - 4 Hours',
    '-3.5' => 'GMT - 3.5 Hours',
    '-3' => 'GMT - 3 Hours',
    '-2' => 'GMT - 2 Hours',
    '-1' => 'GMT - 1 Hours',
    '0' => 'GMT',
    '1' => 'GMT + 1 Hour',
    '2' => 'GMT + 2 Hours',
    '3' => 'GMT + 3 Hours',
    '3.5' => 'GMT + 3.5 Hours',
    '4' => 'GMT + 4 Hours',
    '4.5' => 'GMT + 4.5 Hours',
    '5' => 'GMT + 5 Hours',
    '5.5' => 'GMT + 5.5 Hours',
    '5.75' => 'GMT +5:45 Hours',
    '6' => 'GMT + 6 Hours',
    '6.5' => 'GMT + 6.5 Hours',
    '7' => 'GMT + 7 Hours',
    '8' => 'GMT + 8 Hours',
    '9' => 'GMT + 9 Hours',
    '9.5' => 'GMT + 9.5 Hours',
    '10' => 'GMT + 10 Hours',
    '10.5' => 'GMT + 10.5 Hours',
    '11' => 'GMT + 11 Hours',
    '11.5' => 'GMT + 11.5 Hours',
    '12' => 'GMT + 12 Hours',
    '12.75' => 'GMT + 12:45 Hours',
    '13' => 'GMT + 13 Hours',
    '14' => 'GMT + 14 Hours',
    'tz' => array(
	  -12 => '(GMT -12:00) Eniwetok, Kwajalein',
	  -11 => '(GMT -11:00) Midway Island, Samoa',
	  -10 => '(GMT -10:00) Hawaii',
	  -9 => '(GMT -9:00) Alaska',
	  -8 => '(GMT -8:00) Pacific Time (US &amp; Canada), Tijuana',
	  -7 => '(GMT -7:00) Mountain Time (US &amp; Canada), Arizona',
	  -6 => '(GMT -6:00) Central Time (US &amp; Canada), Mexico City',
	  -5 => '(GMT -5:00) Eastern Time (US &amp; Canada), Bogota, Lima, Quito',
	  -4 => '(GMT -4:00) Atlantic Time (Canada), Caracas, La Paz',
	  '-3.5' => '(GMT -3:30) Newfoundland',
	  -3 => '(GMT -3:00) Brassila, Buenos Aires, Georgetown, Falkland Is',
	  -2 => '(GMT -2:00) Mid-Atlantic, Ascension Is., St. Helena',
	  -1 => '(GMT -1:00) Azores, Cape Verde Islands',
	  0 => '(GMT) Casablanca, Dublin, Edinburgh, London, Lisbon, Monrovia',
	  1 => '(GMT +1:00) Amsterdam, Berlin, Brussels, Madrid, Paris, Rome',
	  2 => '(GMT +2:00) Cairo, Helsinki, Kaliningrad, South Africa, Warsaw',
	  3 => '(GMT +3:00) Baghdad, Riyadh, Moscow, Nairobi',
	  '3.5' => '(GMT +3:30) Tehran',
	  4 => '(GMT +4:00) Abu Dhabi, Baku, Muscat, Tbilisi',
	  '4.5' => '(GMT +4:30) Kabul',
	  5 => '(GMT +5:00) Ekaterinburg, Islamabad, Karachi, Tashkent',
	  '5.5' => '(GMT +5:30) Bombay, Calcutta, Madras, New Delhi',
      '5.75' => '(GMT +5:45) Nepal',
	  6 => '(GMT +6:00) Almaty, Colombo, Dhaka, Novosibirsk',
	  '6.5' => '(GMT +6:30) Rangoon',
	  7 => '(GMT +7:00) Bangkok, Hanoi, Jakarta',
	  8 => '(GMT +8:00) Beijing, Hong Kong, Perth, Singapore, Taipei',
	  9 => '(GMT +9:00) Osaka, Sapporo, Seoul, Tokyo, Yakutsk',
	  '9.5' => '(GMT +9:30) Adelaide, Darwin',
	  10 => '(GMT +10:00) Brisbane, Canberra, Guam, Melbourne, Sydney, Vladivostok',
      '10.5' => '(GMT +10:30) South Australia Summer', 
	  11 => '(GMT +11:00) Magadan, New Caledonia, Solomon Islands',
      '11.5' => '(GMT +11:30) Norfolk Isl. Australia', 
	  12 => '(GMT +12:00) Auckland, Wellington, Fiji, Marshall Island',
      '12.75' => '(GMT +12:45) Chatham Island',
      13 => '(GMT +13:00) Phoenix Islands',
      14 => '(GMT +14:00) Christmas Islands'
    ),

    // Error titles 
    'Information' => 'Information',
    'Critical_Information' => 'Critical Information',
    'General_Error' => 'General Error',
    'Critical_Error' => 'Critical Error',
    'An_error_occured' => 'An Error Occurred',
    'A_critical_error' => 'A Critical Error Occurred',
    // Merge 
    'Refresh' => 'Refresh',
    'Merge_topics' => 'Merge topics',
    'Merge_title' => 'New topic title',
    'Merge_title_explain' => 'This will be the new title of the final topic. Let it blank if you want the system to use the title of the destination topic',
    'Merge_topic_from' => 'Topic to merge',
    'Merge_topic_from_explain' => 'This topic will be merge to the other topic. You can input the topic id, the url of the topic, or the url of a post in this topic',
    'Merge_topic_to' => 'Destination topic',
    'Merge_topic_to_explain' => 'This topic will get all the posts of the precedent topic. You can input the topic id, the url of the topic, or the url of a post in this topic',
    'Merge_from_not_found' => 'The topic to merge hasn\'t been found',
    'Merge_to_not_found' => 'The destination topic hasn\'t been found',
    'Merge_topics_equals' => 'You can merge a topic with itself',
    'Merge_from_not_authorized' => 'You are not a authorized to moderate topics coming from the forum of the topic to merge',
    'Merge_to_not_authorized' => 'You are not a authorized to moderate topics coming from the forum of the destination topic',
    'Merge_poll_from' => 'There is a poll on the topic to merge. It will be copied to the destination topic',
    'Merge_poll_from_and_to' => 'The destination topic already has got a poll. The poll of the topic to merge will be deleted',
    'Merge_confirm_process' => 'Are you sure you want to merge <br />"<b>%s</b>"<br />to<br />"<b>%s</b>"',
    'Merge_topic_done' => 'The topics have been successfully merged.',
    // Quick Reply 
    'Quick_Reply' => 'Quick Reply',
    'Quick_quote' => 'Quote the last message',
    'PMQR_Quick_Reply' => 'Quick Reply',
    'PMQR_Quick_quote' => 'Quote the last message',
    'PMQR_QuoteSelelected' => 'Quote selected',
    'PMQR_QuoteSelelectedEmpty' => 'Select a text anywhere on a page and try again',
    // Attachment 
    'Rules_attach_can' => 'You <b>can</b> attach files in this forum',
    'Rules_attach_cannot' => 'You <b>cannot</b> attach files in this forum',
    'Rules_download_can' => 'You <b>can</b> download files in this forum',
    'Rules_download_cannot' => 'You <b>cannot</b> download files in this forum',
    'Sorry_auth_view_attach' => 'Sorry but you are not authorized to view or download this Attachment',
    'Description' => 'Description',
    'Downloaded' => 'Downloaded',
    'Download' => 'Download',
    'Filesize' => 'Filesize',
    'Viewed' => 'Viewed',
    'Download_number' => '%d Time(s)',
    'Extension_disabled_after_posting' => 'The Extension \'%s\' was deactivated by an board admin, therefore this Attachment is not displayed.',
    'Attach_posting_cp' => 'Attachment Posting Control Panel',
    'Attach_posting_cp_explain' => 'If you click on Add an Attachment, you will see the box for adding Attachments.<br />If you click on Posted Attachments, you will see a list of already attached Files and you are able to edit them.<br />If you want to Replace (Upload new Version) an Attachment, you have to click both links. Add the Attachment as you normally would do, thereafter don\'t click on Add Attachment, rather click on Upload New Version at the Attachment Entry you intend to update.',
    'Add_attachment' => 'Add Attachment',
    'Add_attachment_title' => 'Add an Attachment',
    'Add_attachment_explain' => 'If you do not want to add an Attachment to your Post, please leave the Fields blank',
    'File_name' => 'Filename',
    'File_comment' => 'File Comment',
    'Posted_attachments' => 'Posted Attachments',
    'Update_comment' => 'Update Comment',
    'Delete_attachments' => 'Delete Attachments',
    'Delete_attachment' => 'Delete Attachment',
    'Delete_thumbnail' => 'Delete Thumbnail',
    'Upload_new_version' => 'Upload New Version',
    'Invalid_filename' => '%s is an invalid filename',
    'Attachment_php_size_na' => 'The Attachment is too big.<br />Couldn\'t get the maximum Size defined in PHP.<br />The Attachment Mod is unable to determine the maximum Upload Size defined in the php.ini.',
    'Attachment_php_size_overrun' => 'The Attachment is too big.<br />Maximum Upload Size: %d MB.<br />Please note that this Size is defined in php.ini, this means it\'s set by PHP and the Attachment Mod can not override this value.',
    'Disallowed_extension' => 'The Extension %s is not allowed',
    'Disallowed_extension_within_forum' => 'You are not allowed to post Files with the Extension %s within this Forum',
    'Attachment_too_big' => 'The Attachment is too big.<br />Max Size: %d %s',
    'Attach_quota_reached' => 'Sorry, but the maximum filesize for all Attachments is reached. Please contact the Board Administrator if you have questions.',
    'Too_many_attachments' => 'Attachment cannot be added, since the max. number of %d Attachments in this post was achieved',
    'Error_imagesize' => 'The Attachment/Image must be less than %d pixels wide and %d pixels high',
    'General_upload_error' => 'Upload Error: Could not upload Attachment to %s.',
    'Error_empty_add_attachbox' => 'You have to enter values in the \'Add an Attachment\' Box',
    'Error_missing_old_entry' => 'Unable to Update Attachment, could not find old Attachment Entry',
    'Attach_quota_sender_pm_reached' => 'Sorry, but the maximum filesize for all Attachments in your Private Message Folder has been reached. Please delete some of your received/sent Attachments.',
    'Attach_quota_receiver_pm_reached' => 'Sorry, but the maximum filesize for all Attachments in the Private Message Folder of \'%s\' has been reached. Please let him know, or wait until he/she has deleted some of his/her Attachments.',
    'No_attachment_selected' => 'You haven\'t selected an attachment to download or view.',
    'Error_no_attachment' => 'The selected Attachment does not exist anymore',
    'Confirm_delete_attachments' => 'Are you sure you want to delete the selected Attachments?',
    'Deleted_attachments' => 'The selected Attachments have been deleted.',
    'Error_deleted_attachments' => 'Could not delete Attachments.',
    'Confirm_delete_pm_attachments' => 'Are you sure you want to delete all Attachments posted in this PM?',
    'Attachment_feature_disabled' => 'The Attachment Feature is disabled.',
    'Directory_does_not_exist' => 'The Directory \'%s\' does not exist or couldn\'t be found.',
    'Directory_is_not_a_dir' => 'Please check if \'%s\' is a directory.',
    'Directory_not_writeable' => 'Directory \'%s\' is not writeable. You\'ll have to create the upload path and chmod it to 777 (or change the owner to you httpd-servers owner) to upload files.<br />If you have only plain ftp-access change the \'Attribute\' of the directory to rwxrwxrwx.',
    'Ftp_error_connect' => 'Could not connect to FTP Server: \'%s\'. Please check your FTP-Settings.',
    'Ftp_error_login' => 'Could not login to FTP Server. The Username \'%s\' or the Password is wrong. Please check your FTP-Settings.',
    'Ftp_error_path' => 'Could not access ftp directory: \'%s\'. Please check your FTP Settings.',
    'Ftp_error_upload' => 'Could not upload files to ftp directory: \'%s\'. Please check your FTP Settings.',
    'Ftp_error_delete' => 'Could not delete files in ftp directory: \'%s\'. Please check your FTP Settings.<br />Another reason for this error could be the non-existence of the Attachment, please check this first in Shadow Attachments.',
    'Ftp_error_pasv_mode' => 'Unable to enable/disable FTP Passive Mode',
    'Rules_page' => 'Attachment Rules',
    'Attach_rules_title' => 'Allowed Extension Groups and their Sizes',
    'Group_rule_header' => '%s -> Maximum Upload Size: %s',
    'Allowed_extensions_and_sizes' => 'Allowed Extensions and Sizes',
    'Note_user_empty_group_permissions' => 'NOTE:<br />You are normally allowed to attach files within this Forum, <br />but since no Extension Group is allowed to be attached here, <br />you are unable to attach anything. If you try, <br />you will receive an Error Message.<br />',
    'Upload_quota' => 'Upload Quota',
    'Pm_quota' => 'PM Quota',
    'User_upload_quota_reached' => 'Sorry, you have reached your maximum Upload Quota Limit of %d %s',
    'User_acp_title' => 'User ACP',
    'UACP' => 'User Attachment Control Panel',
    'User_uploaded_profile' => 'Uploaded: %s',
    'User_quota_profile' => 'Quota: %s',
    'Upload_percent_profile' => '%d%% of total',
    // Common Variables 
    'Bytes' => 'Bytes',
    'KB' => 'KB',
    'MB' => 'MB',
    'Attach_search_query' => 'Search Attachments',
    'Test_settings' => 'Test Settings',
    'Not_assigned' => 'Not Assigned',
    'No_file_comment_available' => 'No File Comment available',
    'Attachbox_limit' => 'Your Attachbox is %d%% full',
    'No_quota_limit' => 'No Quota Limit',
    'Unlimited' => 'Unlimited',
	# admin section 
    'General' => 'General Admin',
    'Users' => 'User Admin',
    'Groups' => 'Group Admin',
    'Forums' => 'Forum Admin',
    'Styles' => 'Styles Admin',
    'Configuration' => 'Configuration',
    'Permissions' => 'Permissions',
    'Manage' => 'Management',
    'Disallow' => 'Disallow names',
    'Prune' => 'Pruning',
    'Mass_Email' => 'Mass Email',
    'Ranks' => 'Ranks',
    'Smilies' => 'Smilies',
    'Ban_Management' => 'Ban Control',
    'Word_Censor' => 'Word Censors',
    'Export' => 'Export',
    'Create_new' => 'Create',
    'Add_new' => 'Add',
    'Backup_DB' => 'Backup Database',
    'Restore_DB' => 'Restore Database',
    'Admin' => 'Administration',
    'Not_admin' => 'You are not authorised to administer this board',
    'Welcome_phpBB' => 'Welcome to phpBB',
    'Admin_intro' => 'Thank you for choosing phpBB as your forum solution. This screen will give you a quick overview of all the various statistics of your board. You can get back to this page by clicking on the <u>Admin Index</u> link in the left pane. To return to the index of your board, click the phpBB logo also in the left pane. The other links on the left hand side of this screen will allow you to control every aspect of your forum experience. Each screen will have instructions on how to use the tools.',
    'Main_index' => 'Forum Index',
    'Forum_stats' => 'Forum Statistics',
    'Admin_Index' => 'Admin Index',
    'Preview_forum' => 'Preview Forum',
    'Click_return_admin_index' => 'Click %sHere%s to return to the Admin Index',
    'Statistic' => 'Statistic',
    'Value' => 'Value',
    'Number_posts' => 'Number of posts',
    'Posts_per_day' => 'Posts per day',
    'Number_topics' => 'Number of topics',
    'Topics_per_day' => 'Topics per day',
    'Number_users' => 'Number of users',
    'Users_per_day' => 'Users per day',
    'Board_started' => 'Board started',
    'Avatar_dir_size' => 'Avatar directory size',
    'Database_size' => 'Database size',
    'Gzip_compression' => 'Gzip compression',
    'Not_available' => 'Not available',
    'ON' => 'ON',
    'OFF' => 'OFF',
    'Database_Utilities' => 'Database Utilities',
    'Restore' => 'Restore',
    'Backup' => 'Backup',
    'Restore_explain' => 'This will perform a full restore of all phpBB tables from a saved file. If your server supports it, you may upload a gzip-compressed text file and it will automatically be decompressed. <b>WARNING</b>: This will overwrite any existing data. The restore may take a long time to process, so please do not move from this page until it is complete.',
    'Backup_explain' => 'Here you can back up all your phpBB-related data. If you have any additional custom tables in the same database with phpBB that you would like to back up as well, please enter their names, separated by commas, in the Additional Tables textbox below. If your server supports it you may also gzip-compress the file to reduce its size before download.',
    'Backup_options' => 'Backup options',
    'Start_backup' => 'Start Backup',
    'Full_backup' => 'Full backup',
    'Structure_backup' => 'Structure-Only backup',
    'Data_backup' => 'Data only backup',
    'Additional_tables' => 'Additional tables',
    'Gzip_compress' => 'Gzip compress file',
    'Select_file' => 'Select a file',
    'Start_Restore' => 'Start Restore',
    'Restore_success' => 'The Database has been successfully restored.<br /><br />Your board should be back to the state it was when the backup was made.',
    'Backup_download' => 'Your download will start shortly; please wait until it begins.',
    'Backups_not_supported' => 'Sorry, but database backups are not currently supported for your database system.',
    'Restore_Error_uploading' => 'Error in uploading the backup file',
    'Restore_Error_filename' => 'Filename problem; please try an alternative file',
    'Restore_Error_decompress' => 'Cannot decompress a gzip file; please upload a plain text version',
    'Restore_Error_no_file' => 'No file was uploaded',
    // Auth pages 
    'Select_a_User' => 'Select a User',
    'Select_a_Group' => 'Select a Group',
    'Select_a_Forum' => 'Select a Forum',
    'Auth_Control_User' => 'User Forum Permissions',
    'Auth_Control_Group' => 'Group Forum Permissions',
    'Auth_Control_Forum' => 'Forum Permissions',
    'Look_up_User' => 'Look up User',
    'Look_up_Group' => 'Look up Group',
    'Look_up_Forum' => 'Look up Forum',
    'Group_auth_explain' => 'Here you can alter the permissions and moderator status assigned to each user group. Do not forget when changing group permissions that individual user permissions may still allow the user entry to forums, etc. You will be warned if this is the case.',
    'User_auth_explain' => 'Here you can alter the permissions and moderator status assigned to each individual user. Do not forget when changing user permissions that group permissions may still allow the user entry to forums, etc. You will be warned if this is the case.',
    'Forum_auth_explain' => 'Here you can alter the authorisation levels of each forum. You will have both a simple and advanced method for doing this, where advanced offers greater control of each forum operation. Remember that changing the permission level of forums will affect which users can carry out the various operations within them.',
    'Simple_mode' => 'Simple Mode',
    'Advanced_mode' => 'Advanced Mode',
    'Moderator_status' => 'Moderator status',
    'Allowed_Access' => 'Allowed Access',
    'Disallowed_Access' => 'Disallowed Access',
    'Is_Moderator' => 'Is Moderator',
    'Conflict_warning' => 'Authorisation Conflict Warning',
    'Conflict_access_userauth' => 'This user still has access rights to this forum via group membership. You may want to alter the group permissions or remove this user the group to fully prevent them having access rights. The groups granting rights (and the forums involved) are noted below.',
    'Conflict_mod_userauth' => 'This user still has moderator rights to this forum via group membership. You may want to alter the group permissions or remove this user the group to fully prevent them having moderator rights. The groups granting rights (and the forums involved) are noted below.',
    'Conflict_access_groupauth' => 'The following user (or users) still have access rights to this forum via their user permission settings. You may want to alter the user permissions to fully prevent them having access rights. The users granted rights (and the forums involved) are noted below.',
    'Conflict_mod_groupauth' => 'The following user (or users) still have moderator rights to this forum via their user permissions settings. You may want to alter the user permissions to fully prevent them having moderator rights. The users granted rights (and the forums involved) are noted below.',
    'Public' => 'Public',
    'Private' => 'Private',
    'Registered' => 'Registered',
    'Administrators' => 'Administrators',
    'Hidden' => 'Hidden',
    // These are displayed in the drop down boxes for advanced
    // mode forum auth, try and keep them short!
    'Forum_ALL' => 'ALL',
    'Forum_REG' => 'REG',
    'Forum_PRIVATE' => 'PRIVATE',
    'Forum_MOD' => 'MOD',
    'Forum_ADMIN' => 'ADMIN',
    'View' => 'View',
    'Read' => 'Read',
    'Reply' => 'Reply',
    'Edit' => 'Edit',
    'Sticky' => 'Sticky',
    'Announce' => 'Announce',
    'Vote' => 'Vote',
    'Pollcreate' => 'Poll create',
    'Simple_Permission' => 'Simple Permissions',
    'User_Level' => 'User Level',
    'Auth_User' => 'User',
    'Auth_Admin' => 'Administrator',
    'Group_memberships' => 'Usergroup memberships',
    'Usergroup_members' => 'This group has the following members',
    'Forum_auth_updated' => 'Forum permissions updated',
    'User_auth_updated' => 'User permissions updated',
    'Group_auth_updated' => 'Group permissions updated',
    'Auth_updated' => 'Permissions have been updated',
    'Click_return_userauth' => 'Click %sHere%s to return to User Permissions',
    'Click_return_groupauth' => 'Click %sHere%s to return to Group Permissions',
    'Click_return_forumauth' => 'Click %sHere%s to return to Forum Permissions',
    // Banning 
    'Ban_control' => 'Ban Control',
    'Ban_explain' => 'Here you can control the banning of users. You can achieve this by banning either or both of a specific user or an individual or range of IP addresses or hostnames. These methods prevent a user from even reaching the index page of your board. To prevent a user from registering under a different username you can also specify a banned email address. Please note that banning an email address alone will not prevent that user from being able to log on or post to your board. You should use one of the first two methods to achieve this.',
    'Ban_explain_warn' => 'Please note that entering a range of IP addresses results in all the addresses between the start and end being added to the banlist. Attempts will be made to minimise the number of addresses added to the database by introducing wildcards automatically where appropriate. If you really must enter a range, try to keep it small or better yet state specific addresses.',
    'Select_username' => 'Select a Username',
    'Select_ip' => 'Select an IP address',
    'Select_email' => 'Select an Email address',
    'Ban_username' => 'Ban one or more specific users',
    'Ban_username_explain' => 'You can ban multiple users in one go using the appropriate combination of mouse and keyboard for your computer and browser',
    'Ban_IP' => 'Ban one or more IP addresses or hostnames',
    'IP_hostname' => 'IP addresses or hostnames',
    'Ban_IP_explain' => 'To specify several different IP addresses or hostnames separate them with commas. To specify a range of IP addresses, separate the start and end with a hyphen (-); to specify a wildcard, use an asterisk (*).',
    'Ban_email' => 'Ban one or more email addresses',
    'Ban_email_explain' => 'To specify more than one email address, separate them with commas. To specify a wildcard username, use * like *@hotmail.com',
    'Unban_username' => 'Un-ban one more specific users',
    'Unban_username_explain' => 'You can unban multiple users in one go using the appropriate combination of mouse and keyboard for your computer and browser',
    'Unban_IP' => 'Un-ban one or more IP addresses',
    'Unban_IP_explain' => 'You can unban multiple IP addresses in one go using the appropriate combination of mouse and keyboard for your computer and browser',
    'Unban_email' => 'Un-ban one or more email addresses',
    'Unban_email_explain' => 'You can unban multiple email addresses in one go using the appropriate combination of mouse and keyboard for your computer and browser',
    'No_banned_users' => 'No banned usernames',
    'No_banned_ip' => 'No banned IP addresses',
    'No_banned_email' => 'No banned email addresses',
    'Ban_update_sucessful' => 'The banlist has been updated successfully',
    'Click_return_banadmin' => 'Click %sHere%s to return to Ban Control',
    # Board Configuration 
    'General_Config' => 'General Configuration',
    'Config_explain' => 'The form below will allow you to customize all the general board options. For User and Forum configurations use the related links on the left hand side.',
    'Click_return_config' => 'Click %sHere%s to return to General Configuration',
    'General_settings' => 'General Board Settings',
    'Server_name' => 'Domain Name',
    'Server_name_explain' => 'The domain name from which this board runs',
    'Script_path' => 'Script path',
    'Script_path_explain' => 'The path where phpBB2 is located relative to the domain name',
    'Server_port' => 'Server Port',
    'Server_port_explain' => 'The port your server is running on, usually 80. Only change if different',
    'Abilities_settings' => 'User and Forum Basic Settings',
    'Max_poll_options' => 'Max number of poll options',
    'Flood_Interval' => 'Flood Interval',
    'Flood_Interval_explain' => 'Number of seconds a user must wait between posts',
    'Board_email_form' => 'User email via board',
    'Board_email_form_explain' => 'Users send email to each other via this board',
    'Topics_per_page' => 'Topics Per Page',
    'Posts_per_page' => 'Posts Per Page',
    'Hot_threshold' => 'Posts for Popular Threshold',
    'Default_style' => 'Default Style',
    'Override_style' => 'Override user style',
    'Override_style_explain' => 'Replaces users style with the default',
    'System_timezone' => 'System Timezone',
    'Enable_gzip' => 'Enable GZip Compression',
    'Enable_prune' => 'Enable Forum Pruning',
    'Allow_HTML' => 'Allow HTML',
    'Allow_BBCode' => 'Allow BBCode',
    'Allowed_tags' => 'Allowed HTML tags',
    'Allowed_tags_explain' => 'Separate tags with commas',
    'Allow_smilies' => 'Allow Smilies',
    'Allow_sig' => 'Allow Signatures',
    'Max_sig_length' => 'Maximum signature length',
    'Max_sig_length_explain' => 'Maximum number of characters in user signatures',
    'Allow_forum_watch' => 'Allow Forum Watch',
	'Recycle_allow' => 'Allow Topic/Post Recycling',
	'Recycle_forum' => 'Select a forum for recycled topics/posts<br />(beware the permissions you set)',
	'Allow_online_index' => 'Display users currently online',
	'Online_index_group' => 'Select group allowed to view users currently online',
	'Allow_online_today' => 'Display users online for today',
	'Online_today_group' => 'Select group allowed to view users online today',
    'Allow_name_change' => 'Allow Username changes',
    'COPPA_settings' => 'COPPA Settings',
    'COPPA_fax' => 'COPPA Fax Number',
    'COPPA_mail' => 'COPPA Mailing Address',
    'COPPA_mail_explain' => 'This is the mailing address to which parents will send COPPA registration forms',
    'Disable_privmsg' => 'Private Messaging',
    'Inbox_limits' => 'Max posts in Inbox',
    'Sentbox_limits' => 'Max posts in Sentbox',
    'Savebox_limits' => 'Max posts in Savebox',
    'Visual_confirm' => 'Enable Visual Confirmation',
    'Visual_confirm_explain' => 'Requires users enter a code defined by an image when registering.',
    // Forum Management 
    'Forum_admin' => 'Forum Administration',
    'Forum_admin_explain' => 'From this panel you can add, delete, edit, re-order and re-synchronise categories and forums',
    'Edit_forum' => 'Edit forum',
    'Create_forum' => 'Create new forum',
    'Create_category' => 'Create new category',
    'Remove' => 'Remove',
    'Action' => 'Action',
    'Update_order' => 'Update Order',
    'Config_updated' => 'Forum Configuration Updated Successfully',
    'Move_up' => 'Move up',
    'Move_down' => 'Move down',
    'Resync' => 'Resync',
    'No_mode' => 'No mode was set',
    'Forum_edit_delete_explain' => 'The form below will allow you to customize all the general board options. For User and Forum configurations use the related links on the left hand side',
    'Move_contents' => 'Move all contents',
    'Forum_delete' => 'Delete Forum',
    'Forum_delete_explain' => 'The form below will allow you to delete a forum (or category) and decide where you want to put all topics (or forums) it contained.',
    'Status_locked' => 'Locked',
    'Status_unlocked' => 'Unlocked',
    'Forum_settings' => 'General Forum Settings',
    'Forum_name' => 'Forum name',
    'Forum_desc' => 'Description',
    'Forum_status' => 'Forum status',
    'Forum_pruning' => 'Auto-pruning',
    'prune_freq' => 'Check for topic age every',
    'prune_days' => 'Remove topics that have not been posted to in',
    'Set_prune_data' => 'You have turned on auto-prune for this forum but did not set a frequency or number of days to prune. Please go back and do so.',
    'Move_and_Delete' => 'Move and Delete',
    'Delete_all_posts' => 'Delete all posts',
    'Nowhere_to_move' => 'Nowhere to move to',
    'Edit_Category' => 'Edit Category',
    'Edit_Category_explain' => 'Use this form to modify a category\'s name.',
    'Forums_updated' => 'Forum and Category information updated successfully',
    'Must_delete_forums' => 'You need to delete all forums before you can delete this category',
    'Click_return_forumadmin' => 'Click %sHere%s to return to Forum Administration',
    'smiley_title' => 'Smiles Editing Utility',
    'smile_desc' => 'From this page you can add, remove and edit the emoticons or smileys that your users can use in their posts and private messages.',
    'smiley_config' => 'Smiley Configuration',
    'smiley_code' => 'Smiley Code',
    'smiley_url' => 'Smiley Image File',
    'smiley_emot' => 'Smiley Emotion',
    'smile_add' => 'Add a new Smiley',
    'Smile' => 'Smile',
    'Emotion' => 'Emotion',
    'Select_pak' => 'Select Pack (.pak) File',
    'replace_existing' => 'Replace Existing Smiley',
    'keep_existing' => 'Keep Existing Smiley',
    'smiley_import_inst' => 'You should unzip the smiley package and upload all files to the appropriate Smiley directory for your installation. Then select the correct information in this form to import the smiley pack.',
    'smiley_import' => 'Smiley Pack Import',
    'choose_smile_pak' => 'Choose a Smile Pack .pak file',
    'import' => 'Import Smileys',
    'smile_conflicts' => 'What should be done in case of conflicts',
    'del_existing_smileys' => 'Delete existing smileys before import',
    'import_smile_pack' => 'Import Smiley Pack',
    'export_smile_pack' => 'Create Smiley Pack',
    'export_smiles' => 'To create a smiley pack from your currently installed smileys, click %sHere%s to download the smiles.pak file. Name this file appropriately making sure to keep the .pak file extension.  Then create a zip file containing all of your smiley images plus this .pak configuration file.',
    'smiley_add_success' => 'The Smiley was successfully added',
    'smiley_edit_success' => 'The Smiley was successfully updated',
    'smiley_import_success' => 'The Smiley Pack was imported successfully!',
    'smiley_del_success' => 'The Smiley was successfully removed',
    'Click_return_smileadmin' => 'Click %sHere%s to return to Smiley Administration',
    'User_admin' => 'User Administration',
    'User_admin_explain' => 'Here you can change your users\' information and certain options. To modify the users\' permissions, please use the user and group permissions system.',
    'Look_up_user' => 'Look up user',
    'Admin_user_fail' => 'Couldn\'t update the user\'s profile.',
    'Admin_user_updated' => 'The user\'s profile was successfully updated.',
    'Click_return_useradmin' => 'Click %sHere%s to return to User Administration',
    'User_delete' => 'Delete this user',
    'User_delete_explain' => 'Click here to delete this user; this cannot be undone.',
    'User_deleted' => 'User was successfully deleted.',
    'User_status' => 'User is active',
    'User_allowpm' => 'Can send Private Messages',
    'User_allowavatar' => 'Can display avatar',
    'Admin_avatar_explain' => 'Here you can see and delete the user\'s current avatar.',
    'User_special' => 'Special admin-only fields',
    'User_special_explain' => 'These fields are not able to be modified by the users.  Here you can set their status and other options that are not given to users.',
    'Group_administration' => 'Group Administration',
    'Group_admin_explain' => 'From this panel you can administer all your usergroups. You can delete, create and edit existing groups. You may choose moderators, toggle open/closed group status and set the group name and description',
    'Error_updating_groups' => 'There was an error while updating the groups',
    'Updated_group' => 'The group was successfully updated',
    'Added_new_group' => 'The new group was successfully created',
    'Deleted_group' => 'The group was successfully deleted',
    'New_group' => 'Create new group',
    'Edit_group' => 'Edit group',
    'group_name' => 'Group name',
    'group_description' => 'Group description',
    'group_moderator' => 'Group moderator',
    'group_status' => 'Group status',
    'group_open' => 'Open group',
    'group_closed' => 'Closed group',
    'group_hidden' => 'Hidden group',
    'group_delete' => 'Delete group',
    'group_delete_check' => 'Delete this group',
    'submit_group_changes' => 'Submit Changes',
    'reset_group_changes' => 'Reset Changes',
    'No_group_name' => 'You must specify a name for this group',
    'No_group_moderator' => 'You must specify a moderator for this group',
    'No_group_mode' => 'You must specify a mode for this group, open or closed',
    'No_group_action' => 'No action was specified',
    'delete_group_moderator' => 'Delete the old group moderator?',
    'delete_moderator_explain' => 'If you\'re changing the group moderator, check this box to remove the old moderator from the group.  Otherwise, do not check it, and the user will become a regular member of the group.',
    'Click_return_groupsadmin' => 'Click %sHere%s to return to Group Administration.',
    'Select_group' => 'Select a group',
    'Look_up_group' => 'Look up group',
    'Forum_Prune' => 'Forum Prune',
    'Forum_Prune_explain' => 'This will delete any topic which has not been posted to within the number of days you select. If you do not enter a number then all topics will be deleted. It will not remove topics in which polls are still running nor will it remove announcements. You will need to remove those topics manually.',
    'Do_Prune' => 'Do Prune',
    'All_Forums' => 'All Forums',
    'Prune_topics_not_posted' => 'Prune topics with no replies in this many days',
    'Topics_pruned' => 'Topics pruned',
    'Posts_pruned' => 'Posts pruned',
    'Prune_success' => 'Pruning of forums was successful',
    'Words_title' => 'Word Censoring',
    'Words_explain' => 'From this control panel you can add, edit, and remove words that will be automatically censored on your forums. In addition people will not be allowed to register with usernames containing these words. Wildcards (*) are accepted in the word field. For example, *test* will match detestable, test* would match testing, *test would match detest.',
    'Word' => 'Word',
    'Edit_word_censor' => 'Edit word censor',
    'Replacement' => 'Replacement',
    'Add_new_word' => 'Add new word',
    'Update_word' => 'Update word censor',
    'Must_enter_word' => 'You must enter a word and its replacement',
    'No_word_selected' => 'No word selected for editing',
    'Word_updated' => 'The selected word censor has been successfully updated',
    'Word_added' => 'The word censor has been successfully added',
    'Word_removed' => 'The selected word censor has been successfully removed',
    'Click_return_wordadmin' => 'Click %sHere%s to return to Word Censor Administration',
    'Mass_email_explain' => 'Here you can email a message to either all of your users or all users of a specific group.  To do this, an email will be sent out to the administrative email address supplied, with a blind carbon copy sent to all recipients. If you are emailing a large group of people please be patient after submitting and do not stop the page halfway through. It is normal for a mass emailing to take a long time and you will be notified when the script has completed',
    'Compose' => 'Compose',
    'Recipients' => 'Recipients',
    'All_users' => 'All Users',
    'Email_successfull' => 'Your message has been sent',
    'Click_return_massemail' => 'Click %sHere%s to return to the Mass Email form',
    'Ranks_title' => 'Rank Administration',
    'Ranks_explain' => 'Using this form you can add, edit, view and delete ranks. You can also create custom ranks which can be applied to a user via the user management facility',
    'Add_new_rank' => 'Add new rank',
    'Rank_title' => 'Rank Title',
    'Rank_special' => 'Set as Special Rank',
    'Rank_minimum' => 'Minimum Posts',
    'Rank_maximum' => 'Maximum Posts',
    'Rank_image' => 'Rank Image',
    'Rank_image_explain' => 'Use this to define a small image associated with the rank',
    'Must_select_rank' => 'You must select a rank',
    'No_assigned_rank' => 'No special rank assigned',
    'Rank_updated' => 'The rank was successfully updated',
    'Rank_added' => 'The rank was successfully added',
    'Rank_removed' => 'The rank was successfully deleted',
    'No_update_ranks' => 'The rank was successfully deleted. However, user accounts using this rank were not updated.  You will need to manually reset the rank on these accounts',
    'Click_return_rankadmin' => 'Click %sHere%s to return to Rank Administration',
    'Disallow_control' => 'Username Disallow Control',
    'Disallow_explain' => 'Here you can control usernames which will not be allowed to be used.  Disallowed usernames are allowed to contain a wildcard character of *.  Please note that you will not be allowed to specify any username that has already been registered. You must first delete that name then disallow it.',
    'Delete_disallow' => 'Delete',
    'Delete_disallow_title' => 'Remove a Disallowed Username',
    'Delete_disallow_explain' => 'You can remove a disallowed username by selecting the username from this list and clicking submit',
    'Add_disallow' => 'Add',
    'Add_disallow_title' => 'Add a disallowed username',
    'Add_disallow_explain' => 'You can disallow a username using the wildcard character * to match any character',
    'No_disallowed' => 'No Disallowed Usernames',
    'Disallowed_deleted' => 'The disallowed username has been successfully removed',
    'Disallow_successful' => 'The disallowed username has been successfully added',
    'Disallowed_already' => 'The name you entered could not be disallowed. It either already exists in the list, exists in the word censor list, or a matching username is present.',
    'Click_return_disallowadmin' => 'Click %sHere%s to return to Disallow Username Administration',
    // Styles Admin 
    'Styles_admin' => 'Styles Administration',
    'Styles_explain' => 'Using this facility you can add, remove and manage styles (templates and themes) available to your users',
    'Styles_addnew_explain' => 'The following list contains all the themes that are available for the templates you currently have. The items on this list have not yet been installed into the phpBB database. To install a theme, simply click the install link beside an entry.',
    'Select_template' => 'Select a Template',
    'Style' => 'Style',
    'Template' => 'Template',
    'Install' => 'Install',
    'Edit_theme' => 'Edit Theme',
    'Edit_theme_explain' => 'In the form below you can edit the settings for the selected theme',
    'Create_theme' => 'Create Theme',
    'Create_theme_explain' => 'Use the form below to create a new theme for a selected template. When entering colours (for which you should use hexadecimal notation) you must not include the initial #, i.e.. CCCCCC is valid, #CCCCCC is not',
    'Export_themes' => 'Export Themes',
    'Export_explain' => 'In this panel you will be able to export the theme data for a selected template. Select the template from the list below and the script will create the theme configuration file and attempt to save it to the selected template directory. If it cannot save the file itself it will give you the option to download it. In order for the script to save the file you must give write access to the webserver for the selected template dir. For more information on this see the phpBB 2 users guide.',
    'Theme_installed' => 'The selected theme has been installed successfully',
    'Style_removed' => 'The selected style has been removed from the database. To fully remove this style from your system you must delete the appropriate style from your templates directory.',
    'Theme_info_saved' => 'The theme information for the selected template has been saved. You should now return the permissions on the theme_info.cfg (and if applicable the selected template directory) to read-only',
    'Theme_updated' => 'The selected theme has been updated. You should now export the new theme settings',
    'Theme_created' => 'Theme created. You should now export the theme to the theme configuration file for safe keeping or use elsewhere',
    'Confirm_delete_style' => 'Are you sure you want to delete this style?',
    'Download_theme_cfg' => 'The exporter could not write the theme information file. Click the button below to download this file with your browser. Once you have downloaded it you can transfer it to the directory containing the template files. You can then package the files for distribution or use elsewhere if you desire',
    'No_template_dir' => 'Could not open the template directory. It may be unreadable by the webserver or may not exist',
    'Cannot_remove_style' => 'You cannot remove the style selected since it is currently the forum default. Please change the default style and try again.',
    'Style_exists' => 'The style name to selected already exists, please go back and choose a different name.',
    'Click_return_styleadmin' => 'Click %sHere%s to return to Style Administration',
    'Theme_settings' => 'Theme Settings',
    'Theme_element' => 'Theme Element',
    'Simple_name' => 'Simple Name',
    'Save_Settings' => 'Save Settings',
    'Stylesheet' => 'CSS Stylesheet',
    'Background_image' => 'Background Image',
    'Background_color' => 'Background Colour',
    'Theme_name' => 'Theme Name',
    'Link_color' => 'Link Colour',
    'Text_color' => 'Text Colour',
    'VLink_color' => 'Visited Link Colour',
    'ALink_color' => 'Active Link Colour',
    'HLink_color' => 'Hover Link Colour',
    'Tr_color1' => 'Table Row Colour 1',
    'Tr_color2' => 'Table Row Colour 2',
    'Tr_color3' => 'Table Row Colour 3',
    'Tr_class1' => 'Table Row Class 1',
    'Tr_class2' => 'Table Row Class 2',
    'Tr_class3' => 'Table Row Class 3',
    'Th_color1' => 'Table Header Colour 1',
    'Th_color2' => 'Table Header Colour 2',
    'Th_color3' => 'Table Header Colour 3',
    'Th_class1' => 'Table Header Class 1',
    'Th_class2' => 'Table Header Class 2',
    'Th_class3' => 'Table Header Class 3',
    'Td_color1' => 'Table Cell Colour 1',
    'Td_color2' => 'Table Cell Colour 2',
    'Td_color3' => 'Table Cell Colour 3',
    'Td_class1' => 'Table Cell Class 1',
    'Td_class2' => 'Table Cell Class 2',
    'Td_class3' => 'Table Cell Class 3',
    'fontface1' => 'Font Face 1',
    'fontface2' => 'Font Face 2',
    'fontface3' => 'Font Face 3',
    'fontsize1' => 'Font Size 1',
    'fontsize2' => 'Font Size 2',
    'fontsize3' => 'Font Size 3',
    'fontcolor1' => 'Font Colour 1',
    'fontcolor2' => 'Font Colour 2',
    'fontcolor3' => 'Font Colour 3',
    'span_class1' => 'Span Class 1',
    'span_class2' => 'Span Class 2',
    'span_class3' => 'Span Class 3',
    'img_poll_size' => 'Polling Image Size [px]',
    'img_pm_size' => 'Private Message Status size [px]',
    'Welcome_install' => 'Welcome to phpBB 2 Installation',
    'Initial_config' => 'Basic Configuration',
    'DB_config' => 'Database Configuration',
    'Admin_config' => 'Admin Configuration',
    'continue_upgrade' => 'Once you have downloaded your config file to your local machine you may\'Continue Upgrade\' button below to move forward with the upgrade process.  Please wait to upload the config file until the upgrade process is complete.',
    'upgrade_submit' => 'Continue Upgrade',
    'Installer_Error' => 'An error has occurred during installation',
    'Previous_Install' => 'A previous installation has been detected',
    'Install_db_error' => 'An error occurred trying to update the database',
    'Re_install' => 'Your previous installation is still active.<br /><br />If you would like to re-install phpBB 2 you should click the Yes button below. Please be aware that doing so will destroy all existing data and no backups will be made! The administrator username and password you have used to login in to the board will be re-created after the re-installation and no other settings will be retained.<br /><br />Think carefully before pressing Yes!',
    'Inst_Step_0' => 'Thank you for choosing phpBB 2. In order to complete this install please fill out the details requested below. Please note that the database you install into should already exist. If you are installing to a database that uses ODBC, e.g. MS Access you should first create a DSN for it before proceeding.',
    'Start_Install' => 'Start Install',
    'Finish_Install' => 'Finish Installation',
    'Default_lang' => 'Default board language',
    'DB_Host' => 'Database Server Hostname / DSN',
    'DB_Name' => 'Your Database Name',
    'DB_Username' => 'Database Username',
    'DB_Password' => 'Database Password',
    'Database' => 'Your Database',
    'Install_lang' => 'Choose Language for Installation',
    'dbms' => 'Database Type',
    'Table_Prefix' => 'Prefix for tables in database',
    'Admin_Username' => 'Administrator Username',
    'Admin_Password' => 'Administrator Password',
    'Admin_Password_confirm' => 'Administrator Password [ Confirm ]',
    'Inst_Step_2' => 'Your admin username has been created.  At this point your basic installation is complete. You will now be taken to a screen which will allow you to administer your new installation. Please be sure to check the General Configuration details and make any required changes. Thank you for choosing phpBB 2.',
    'Unwriteable_config' => 'Your config file is un-writeable at present. A copy of the config file will be downloaded to your computer when you click the button below. You should upload this file to the same directory as phpBB 2. Once this is done you should log in using the administrator name and password you provided on the previous form and visit the admin control center (a link will appear at the bottom of each screen once logged in) to check the general configuration. Thank you for choosing phpBB 2.',
    'Download_config' => 'Download Config',
    'ftp_choose' => 'Choose Download Method',
    'ftp_option' => '<br />Since FTP extensions are enabled in this version of PHP you may also be given the option of first trying to automatically FTP the config file into place.',
    'ftp_instructs' => 'You have chosen to FTP the file to the account containing phpBB 2 automatically.  Please enter the information below to facilitate this process. Note that the FTP path should be the exact path via FTP to your phpBB2 installation as if you were FTPing to it using any normal client.',
    'ftp_info' => 'Enter Your FTP Information',
    'Attempt_ftp' => 'Attempt to FTP config file into place',
    'Send_file' => 'Just send the file to me and I\'ll FTP it manually',
    'ftp_path' => 'FTP path to phpBB 2',
    'ftp_username' => 'Your FTP Username',
    'ftp_password' => 'Your FTP Password',
    'Transfer_config' => 'Start Transfer',
    'NoFTP_config' => 'The attempt to FTP the config file into place failed.  Please download the config file and FTP it into place manually.',
    'Upgrade' => 'Upgrade',
    'Install_Method' => 'Choose your installation method',
    'Install_No_Ext' => 'The PHP configuration on your server doesn\'t support the database type that you chose',
    'Install_No_PCRE' => 'phpBB2 Requires the Perl-Compatible Regular Expressions Module for PHP which your PHP configuration doesn\'t appear to support!',
    // Attachment Mod and Quick Reply Admin Language Variables 
    'ropm_quick_reply' => 'PM Quick Reply',
    'enable_ropm_quick_reply' => 'Enable PM Quick Reply',
    'ropm_quick_reply_bbc' => 'Enable BBCode-Buttons',
    'Control_Panel' => 'Control Panel',
    'Shadow_attachments' => 'Shadow Attachments',
    'Forbidden_extensions' => 'Forbidden Extensions',
    'Extension_control' => 'Extension Control',
    'Extension_group_manage' => 'Extension Groups Control',
    'Special_categories' => 'Special Categories',
    'Sync_attachments' => 'Synchronize Attachments',
    'Quota_limits' => 'Quota Limits',
    'Attach_settings' => 'Attachment Settings',
    'Manage_attachments_explain' => 'Here you can configure the Main Settings for the Attachment Mod. If you press the Test Settings Button, the Attachment Mod does a few System Tests to be sure that the Mod will work properly. If you have problems with uploading Files, please run this Test, to become a detailed error-message.',
    'Attach_filesize_settings' => 'Attachment Filesize Settings',
    'Attach_number_settings' => 'Attachment Number Settings',
    'Attach_options_settings' => 'Attachment Options',
    'Upload_directory' => 'Upload Directory',
    'Upload_directory_explain' => 'Enter the relative path from your phpBB2 installation to the Attachments upload directory. For example, enter \'files\' if your phpBB2 Installation is located at http://www.yourdomain.com/phpBB2 and the Attachment Upload Directory is located at http://www.yourdomain.com/phpBB2/files.',
    'Attach_img_path' => 'Attachment Posting Icon',
    'Attach_img_path_explain' => 'This Image is displayed next to Attachment Links in individual Postings. Leave this field empty if you don\'t want an icon to be displayed. This Setting will be overwritten by the Settings in Extension Groups Management.',
    'Attach_topic_icon' => 'Attachment Topic Icon',
    'Attach_topic_icon_explain' => 'This Image is displayed before topics with Attachments. Leave this field empty if you don\'t want an icon to be displayed.',
    'Attach_display_order' => 'Attachment Display Order',
    'Attach_display_order_explain' => 'Here you can choose whether to display the Attachments in Posts/PMs in Descending Filetime Order (Newest Attachment First) or Ascending Filetime Order (Oldest Attachment First).',
    'Show_apcp' => 'Show new Attachment Posting Control Panel',
    'Show_apcp_explain' => 'Choose whether to display the Attachment Posting Control Panel (yes) or the old method with two Boxes for Attaching Files and editing your posted Attachments (no) within your Posting Screen. The look of it is very hard to explain, therefore it\'s best to try it out.',
    'Max_filesize_attach' => 'Filesize',
    'Max_filesize_attach_explain' => 'Maximum filesize for Attachments. A value of 0 means \'unlimited\'. This Setting is restricted by your Server Configuration. For example, if your php Configuration only allows a maximum of 2 MB uploads, this cannot be overwritten by the Mod.',
    'Attach_quota' => 'Attachment Quota',
    'Attach_quota_explain' => 'Maximum Disk Space ALL Attachments can hold on your Webspace. A value of 0 means \'unlimited\'.',
    'Max_filesize_pm' => 'Maximum Filesize in Private Messages Folder',
    'Max_filesize_pm_explain' => 'Maximum Disk Space Attachments can use up in each User\'s Private Message box. A value of 0 means \'unlimited\'.',
    'Default_quota_limit' => 'Default Quota Limit',
    'Default_quota_limit_explain' => 'Here you are able to select the Default Quota Limit automatically assigned to newly registered Users and Users without an defined Quota Limit. The Option \'No Quota Limit\' is for not using any Attachment Quotas, instead using the default Settings you have defined within this Management Panel.',
    'Max_attachments' => 'Maximum Number of Attachments',
    'Max_attachments_explain' => 'The maximum number of attachments allowed in one post.',
    'Max_attachments_pm' => 'Maximum number of Attachments in one Private Message',
    'Max_attachments_pm_explain' => 'Define the maximum number of attachments the user is allowed to include in a private message.',
    'Disable_mod' => 'Disable Attachment Mod',
    'Disable_mod_explain' => 'This option is mainly for testing new templates or themes, it disables all Attachment Functions except the Admin Panel.',
    'PM_Attachments' => 'Allow Attachments in Private Messages',
    'PM_Attachments_explain' => 'Allow/Disallow attaching files to Private Messages.',
    'Ftp_upload' => 'Enable FTP Upload',
    'Ftp_upload_explain' => 'Enable/Disable the FTP Upload option. If you set it to yes, you have to define the Attachment FTP Settings and the Upload Directory is no longer used.',
    'Attachment_topic_review' => 'Do you want to display Attachments in the Topic Review Window ?',
    'Attachment_topic_review_explain' => 'If you choose yes, all attached Files will be displayed in Topic Review when you post a reply.',
    'Ftp_server' => 'FTP Upload Server',
    'Ftp_server_explain' => 'Here you can enter the IP-Address or FTP-Hostname of the Server used for your uploaded files. If you leave this field empty, the Server on which your phpBB2 Board is installed will be used. Please note that it is not allowed to add ftp:// or something else to the address, just plain ftp.foo.com or, which is a lot faster, the plain IP Address.',
    'Attach_ftp_path' => 'FTP Path to your upload directory',
    'Attach_ftp_path_explain' => 'The Directory where your Attachments will be stored. This Directory doesn\'t have to be chmodded. Please don\'t enter your IP or FTP-Address here, this input field is only for the FTP Path.<br />For example: /home/web/uploads',
    'Ftp_download_path' => 'Download Link to FTP Path',
    'Ftp_download_path_explain' => 'Enter the URL to your FTP Path, where your Attachments are stored.<br />If you are using a Remote FTP Server, please enter the complete url, for example http://www.mystorage.com/phpBB2/upload.<br />If you are using your Local Host to store your Files, you are able to enter the url path relative to your phpBB2 Directory, for example \'upload\'.<br />A trailing slash will be removed. Leave this field empty, if the FTP Path is not accessible from the Internet. With this field empty you are unable to use the physical download method.',
    'Ftp_passive_mode' => 'Enable FTP Passive Mode',
    'Ftp_passive_mode_explain' => 'The PASV command requests that the remote server open a port for the data connection and return the address of that port. The remote server listens on that port and the client connects to it.',
    'No_ftp_extensions_installed' => 'You are not able to use the FTP Upload Methods, because FTP Extensions are not compiled into your PHP Installation.',
    'Shadow_attachments_explain' => 'Here you can delete attachment data from postings when the files are missing from your filesystem, and delete files that are no longer attached to any postings. You can download or view a file if you click on it; if no link is present, the file does not exist.',
    'Shadow_attachments_file_explain' => 'Delete all attachments files that exist on your filesystem and are not assigned to an existing post.',
    'Shadow_attachments_row_explain' => 'Delete all posting attachment data for files that don\'t exist on your filesystem.',
    'Empty_file_entry' => 'Empty File Entry',
    'Sync_thumbnail_resetted' => 'Thumbnail resetted for Attachment: %s',
    'Attach_sync_finished' => 'Attachment Syncronization Finished.',
    'Manage_extensions' => 'Manage Extensions',
    'Manage_extensions_explain' => 'Here you can manage your File Extensions. If you want to allow/disallow a Extension to be uploaded, please use the Extension Groups Management.',
    'Explanation' => 'Explanation',
    'Extension_group' => 'Extension Group',
    'Invalid_extension' => 'Invalid Extension',
    'Extension_exist' => 'The Extension %s already exist',
    'Unable_add_forbidden_extension' => 'The Extension %s is forbidden, you are not able to add it to the allowed Extensions',
    'Manage_extension_groups' => 'Manage Extension Groups',
    'Manage_extension_groups_explain' => 'Here you can add, delete and modify your Extension Groups, you can disable Extension Groups, assign a special Category to them, change the download mechanism and you can define a Upload Icon which will be displayed in front of an Attachment belonging to the Group.',
    'Special_category' => 'Special Category',
    'Category_images' => 'Images',
    'Category_stream_files' => 'Stream Files',
    'Category_swf_files' => 'Flash Files',
    'Allowed' => 'Allowed',
    'Allowed_forums' => 'Allowed Forums',
    'Ext_group_permissions' => 'Group Permissions',
    'Download_mode' => 'Download Mode',
    'Upload_icon' => 'Upload Icon',
    'Max_groups_filesize' => 'Maximum Filesize',
    'Extension_group_exist' => 'The Extension Group %s already exist',
    'Collapse' => '+',
    'Decollapse' => '-',
    'Manage_categories' => 'Manage Special Categories',
    'Manage_categories_explain' => 'Here you can configure the Special Categories. You can set up Special Parameters and Conditions for the Special Categorys assigned to an Extension Group.',
    'Settings_cat_images' => 'Settings for Special Category: Images',
    'Settings_cat_streams' => 'Settings for Special Category: Stream Files',
    'Settings_cat_flash' => 'Settings for Special Category: Flash Files',
    'Display_inlined' => 'Display Images Inlined',
    'Display_inlined_explain' => 'Choose whether to display images directly within the post (yes) or to display images as a link ?',
    'Max_image_size' => 'Maximum Image Dimensions',
    'Max_image_size_explain' => 'Here you can define the maximum allowed Image Dimension to be attached (Width x Height in pixels).<br />If it is set to 0x0, this feature is disabled. With some Images this Feature will not work due to limitations in PHP.',
    'Image_link_size' => 'Image Link Dimensions',
    'Image_link_size_explain' => 'If this defined Dimension of an Image is reached, the Image will be displayed as a Link, rather than displaying it inlined,<br />if Inline View is enabled (Width x Height in pixels).<br />If it is set to 0x0, this feature is disabled. With some Images this Feature will not work due to limitations in PHP.',
    'Assigned_group' => 'Assigned Group',
    'Image_create_thumbnail' => 'Create Thumbnail',
    'Image_create_thumbnail_explain' => 'Always create a Thumbnail. This feature overrides nearly all Settings within this Special Category, except of the Maximum Image Dimensions. With this Feature a Thumbnail will be displayed within the post, the User can click it to open the real Image.<br />Please Note that this feature requires Imagick to be installed, if it\'s not installed or if Safe-Mode is enabled the GD-Extension of PHP will be used. If the Image-Type is not supported by PHP, this Feature will be not used.',
    'Image_min_thumb_filesize' => 'Minimum Thumbnail Filesize',
    'Image_min_thumb_filesize_explain' => 'If a Image is smaller than this defined Filesize, no Thumbnail will be created, because it\'s small enough.',
    'Image_imagick_path' => 'Imagick Program (Complete Path)',
    'Image_imagick_path_explain' => 'Enter the Path to the convert program of imagick, normally /usr/bin/convert (on windows: c:/imagemagick/convert.exe).',
    'Image_search_imagick' => 'Search Imagick',
    'Use_gd2' => 'Make use of GD2 Extension',
    'Use_gd2_explain' => 'PHP is able to be compiled with the GD1 or GD2 Extension for image manipulating. To correctly create Thumbnails without imagemagick the Attachment Mod uses two different methods, based on your selection here. If your thumbnails are in a bad quality or screwed up, try to change this setting.',
    'Attachment_version' => 'Attachment Mod Version %s',
    'Manage_forbidden_extensions' => 'Manage Forbidden Extensions',
    'Manage_forbidden_extensions_explain' => 'Here you can add or delete the forbidden extensions. The Extensions php, php3 and php4 are forbidden by default for security reasons, you can not delete them.',
    'Forbidden_extension_exist' => 'The forbidden Extension %s already exist',
    'Extension_exist_forbidden' => 'The Extension %s is defined in your allowed Extensions, please delete it their before you add it here.',
    'Group_permissions_title' => 'Extension Group Permissions -> \'%s\'',
    'Group_permissions_explain' => 'Here you are able to restrict the selected Extension Group to Forums of your choice (defined in the Allowed Forums Box). The Default is to allow Extension Groups to all Forums the User is able to Attach Files into (the normal way the Attachment Mod did it since the beginning). Just add those Forums you want the Extension Group (the Extensions within this Group) to be allowed there, the default ALL FORUMS will disappear when you add Forums to the List. You are able to re-add ALL FORUMS at any given Time. If you add a Forum to your Board and the Permission is set to ALL FORUMS nothing will change. But if you have changed and restricted the access to certain Forums, you have to check back here to add your newly created Forum. It is easy to do this automatically, but this will force you to edit a bunch of Files, therefore i have chosen the way it is now. Please keep in mind, that all of your Forums will be listed here.',
    'Note_admin_empty_group_permissions' => 'NOTE:<br />Within the below listed Forums your Users are normally allowed to attach files, but since no Extension Group is allowed to be attached there, your Users are unable to attach anything. If they try, they will receive Error Messages. Maybe you want to set the Permission \'Post Files\' to ADMIN at these Forums.<br /><br />',
    'Add_forums' => 'Add Forums',
    'Add_selected' => 'Add Selected',
    'Perm_all_forums' => 'ALL FORUMS',
    'Manage_quotas' => 'Manage Attachment Quota Limits',
    'Manage_quotas_explain' => 'Here you are able to add/delete/change Quota Limits. You are able to assign these Quota Limits to Users and Groups later. To assign a Quota Limit to a User, you have to go to Users->Management, select the User and you will see the Options at the bottom. To assign a Quota Limit to a Group, go to Groups->Management, select the Group to edit it, and you will see the Configuration Settings. If you want to see, which Users and Groups are assigned to a specific Quota Limit, click on \'View\' at the left of the Quota Description.',
    'Assigned_users' => 'Assigned Users',
    'Assigned_groups' => 'Assigned Groups',
    'Quota_limit_exist' => 'The Quota Limit %s exist already.',
    'Control_panel_title' => 'File Attachment Control Panel',
    'Control_panel_explain' => 'Here you can view and manage all attachments based on Users, Attachments, Views etc...',
    'File_comment_cp' => 'File Comment',
    'Search_wildcard_explain' => 'Use * as a wildcard for partial matches',
    'Size_smaller_than' => 'Attachment size smaller than (bytes)',
    'Size_greater_than' => 'Attachment size greater than (bytes)',
    'Count_smaller_than' => 'Download count is smaller than',
    'Count_greater_than' => 'Download count is greater than',
    'More_days_old' => 'More than this many days old',
    'No_attach_search_match' => 'No Attachments met your search criteria',
    'Number_of_attachments' => 'Number of Attachments',
    'Total_filesize' => 'Total Filesize',
    'Number_posts_attach' => 'Number of Posts with Attachments',
    'Number_topics_attach' => 'Number of Topics with Attachments',
    'Number_users_attach' => 'Independent Users Posted Attachments',
    'Number_pms_attach' => 'Total Number of Attachments in Private Messages',
    'Statistics_for_user' => 'Attachment Statistics for %s',
    'Size_in_kb' => 'Size (KB)',
    'Downloads' => 'Downloads',
    'Post_time' => 'Post Time',
    'Posted_in_topic' => 'Posted in Topic',
    'Submit_changes' => 'Submit Changes',
    'Sort_Attachments' => 'Attachments',
    'Sort_Size' => 'Size',
    'Sort_Filename' => 'Filename',
    'Sort_Comment' => 'Comment',
    'Sort_Extension' => 'Extension',
    'Sort_Downloads' => 'Downloads',
    'Sort_Posttime' => 'Post Time',
    'View_Statistic' => 'Statistics',
    'View_Search' => 'Search',
    'View_Username' => 'Username',
    'View_Attachments' => 'Attachments',
    'Attach_config_updated' => 'Attachment Configuration updated successfully',
    'Click_return_attach_config' => 'Click %sHere%s to return to Attachment Configuration',
    'Test_settings_successful' => 'Settings Test finished, configuration seems to be fine.',
    'Attachments' => 'Attachments',
    'Attachment' => 'Attachment',
    'Extensions' => 'Extensions',
    'Extension' => 'Extension',
    'Auth_attach' => 'Post Files',
    'Auth_download' => 'Download Files',
    'Group_quota' => 'Group quota',
    'Topic_icons' => 'Topic icons',

	# Archive related language defines
    'Archive' => 'Archiving',
    'Enable_archive' => 'Enable Forum Archiving',
    'Forum_archiving' => 'Auto-archiving',
    'archive_freq' => 'Check for topic age every',
    'archive_days' => 'Remove topics that have not been posted to in',
    'Set_archive_data' => 'You have turned on auto-archive for this forum but did not set a frequency or number of days to archive. Please go back and do so.',
    'Forum_Archive' => 'Forum Archive',
    'Forum_Archive_explain' => 'This will archive any posts for topics which have not been posted to within the number of days you select. If you do not enter a number then all topics will be archived. It will not remove posts for topics in which polls are still running nor will it remove announcements or attachments. You will need to archive those topics manually.',
    'Do_Archive' => 'Do Archive',
    'Archive_topics_not_posted' => 'Archive topics with no replies in this many days',
	'Topic_Archived' => 'Topic Archived',
    'Topics_archived' => 'Topics archived',
    'Posts_archived' => 'Posts archived',
    'Archive_success' => 'Archiving of forums was successful',
    'Topics_Archived' => 'The posts for the selected topics have been successfully archived.',
	'Words_Removed' => 'Search Words Removed',
	'Archive_topic' => 'Archive this topic',
	'Revive_topic' => 'Revive this topic',
    'Confirm_archive_topic' => 'Are you sure you want to archive the selected topic/s?',
    'Revive_an_archived_topic' => 'Revive an archived topic',
	'Click_to_revive' => 'Click to Revive Topic',
	'Is_revived' => 'This Archived topic has been revived.',
	'Revived_click_here' => 'Click here to view it.',
    'Archive_Revive' => 'Archive Revive',
    'Archive_Revive_Notes' => 'This is an archived topic - your reply will not be appended here.<br />Instead, a new topic will be generated in the active forum.<br />The new topic will provide a reference link to this archived topic.<br />',
	'View_Archives' => 'View the Forum Archives',
	'View_Active' => 'View the Active Forum',
	'Archives' => 'Archives',
	'Archived' => 'Archived',
    'Cannot_edit_replied' => 'Sorry, but you may not edit posts that have been replied to.',
	'Edit_last_post_only' => 'Restrict user edits, when allowed, to the last post.',

	# Cloak language defines
	'Allow_user_cloak' => 'Allow User Cloaking',
	'Allow_user_cloak_explain' => 'If a user cloaks another user, then the cloakee\'s posts will not be displayed to the cloaker.',
	'Cloak_users' => 'Cloak Users',
	'Cloak_user' => 'Cloak user\'s posts',
	'Cloak_user_stop' => 'Stop cloaking user\'s posts',
	'Cloak_user_bypass' => 'display all cloaked posts',
	'Post_cloaked' => 'Post cloaked',
	'Cloaking_none_selected' => 'You did not select any users to stop cloaking',
	'Cloaking_stopped' => 'Stopped cloaking users',
	'Cloaking_stop' => 'Stop Cloaking',
	'No_user_cloaked' => 'You are not cloaking any users',
	'Allow_cloak_group' => 'Select group allowed to cloak other users',

	# Privileges
	'No_cigar' => 'Nice try, but no cigar - untouchable.',
	'Another_User' => 'Another User',
	'Privileges' => 'Privileges',
	'User_Forum_Privileges' => 'User Forum Privileges',
	'User_forum_explain' => 'Here you can remove posting privileges for an individual user, on a forum basis, or restore those same privileges at a later time.<br />The privileges affected are post, reply, edit, delete, create polls, vote, attach and download files.<br />Note: you cannot remove those privileges for designated administrators and moderators.',

	# Restricted Group
	'Restricted_group' => 'Restricted Group',
	'Restricted_group_explain' => 'The chosen group loses privileges in all forums where authorization levels are set to REG.',

);